==> cattle_grid-0.2.1-py3-none-any.whl: cattle_grid/extensions/examples/simple_storage/test_handlers.py <==
import pytest
from unittest.mock import AsyncMock, MagicMock

from sqlalchemy.ext.asyncio import async_sessionmaker
from sqlalchemy.future import select

from cattle_grid.testing.fixtures import *  # noqa
from cattle_grid.dependencies.globals import alchemy_database

from . import lifespan, simple_storage_publish_activity, simple_storage_publish_object
from .config import SimpleStorageConfiguration
from .message_types import PublishActivity, PublishObject
from .models import StoredActivity, StoredObject

activity_stub = {
    "@context": "https://www.w3.org/ns/activitystreams",
    "type": "AnimalSound",
    "actor": "http://alice.example",
    "to": ["http://bob.example"],
    "content": "moo",
}

object_stub = {
    "@context": "https://www.w3.org/ns/activitystreams",
    "type": "Note",
    "attributedTo": "http://alice.example",
    "to": ["http://bob.example"],
    "content": "moo",
}


@pytest.fixture(autouse=True)
async def sql_engine():
    async with alchemy_database("sqlite+aiosqlite:///:memory:", echo=True) as engine:
        async with lifespan(engine):
            yield engine


@pytest.mark.parametrize(
    "actor,activity",
    [
        ("http://bob.example", activity_stub),
        (
            "http://alice.example",
            {**activity_stub, "id": "http://alice.example/activity1"},
        ),
    ],
)
async def test_simple_storage_publish_activity_errors(actor, activity):
    msg = PublishActivity(
        actor=actor,
        data=activity,
    )

    with pytest.raises(ValueError):
        await simple_storage_publish_activity(
            msg, AsyncMock(), MagicMock(), AsyncMock()
        )


async def test_simple_storage_activity(sql_engine, test_actor):
    msg = PublishActivity(actor="http://alice.example", data=activity_stub)

    broker = AsyncMock()
    config = SimpleStorageConfiguration(prefix="/simple/storage/")

    async_session = async_sessionmaker(sql_engine, expire_on_commit=False)

    async with async_session() as session:
        await simple_storage_publish_activity(
            msg, config, broker=broker, session=session
        )
        await session.commit()

    broker.publish.assert_awaited_once()

    async with async_session() as session:
        result = (await session.scalars(select(StoredActivity))).all()

        assert len(result) == 1

        assert result[0].data.get("id")


@pytest.mark.parametrize(
    "actor,object",
    [
        ("http://bob.example", object_stub),
        (
            "http://alice.example",
            {**object_stub, "id": "http://alice.example/activity1"},
        ),
    ],
)
async def test_simple_storage_publish_object_errors(actor, object):
    msg = PublishObject(
        actor=actor,
        data=object,
    )

    with pytest.raises(ValueError):
        await simple_storage_publish_object(msg, AsyncMock(), MagicMock(), AsyncMock())


async def test_simple_storage_object(sql_engine, test_actor):
    obj = object_stub.copy()
    obj["attributedTo"] = test_actor.actor_id
    msg = PublishObject(actor=test_actor.actor_id, data=obj)

    broker = AsyncMock()
    config = SimpleStorageConfiguration(prefix="/simple/storage/")

    async_session = async_sessionmaker(sql_engine, expire_on_commit=False)

    async with async_session() as session:
        await simple_storage_publish_object(msg, config, broker=broker, session=session)
        await session.commit()

    broker.publish.assert_awaited_once()

    async with async_session() as session:
        result = (await session.scalars(select(StoredActivity))).all()

        assert len(result) == 1

        assert result[0].data.get("id")

        result = (await session.scalars(select(StoredObject))).all()

        assert len(result) == 1

        assert result[0].data.get("id")

==> cattle_grid-0.2.8-py3-none-any.whl: cattle_grid/extensions/examples/simple_storage/test_handlers.py <==
import pytest
from unittest.mock import AsyncMock, MagicMock

from sqlalchemy.ext.asyncio import async_sessionmaker
from sqlalchemy.future import select

from cattle_grid.testing.fixtures import *  # noqa
from cattle_grid.dependencies.globals import global_container

from . import lifespan, simple_storage_publish_activity, simple_storage_publish_object
from .config import SimpleStorageConfiguration
from .message_types import PublishActivity, PublishObject
from .models import StoredActivity, StoredObject

activity_stub = {
    "@context": "https://www.w3.org/ns/activitystreams",
    "type": "AnimalSound",
    "actor": "http://alice.example",
    "to": ["http://bob.example"],
    "content": "moo",
}

object_stub = {
    "@context": "https://www.w3.org/ns/activitystreams",
    "type": "Note",
    "attributedTo": "http://alice.example",
    "to": ["http://bob.example"],
    "content": "moo",
}


@pytest.fixture(autouse=True)
async def sql_engine():
    async with global_container.alchemy_database(
        "sqlite+aiosqlite:///:memory:", echo=True
    ) as engine:
        async with lifespan(engine):
            yield engine


@pytest.mark.parametrize(
    "actor,activity",
    [
        ("http://bob.example", activity_stub),
        (
            "http://alice.example",
            {**activity_stub, "id": "http://alice.example/activity1"},
        ),
    ],
)
async def test_simple_storage_publish_activity_errors(actor, activity):
    msg = PublishActivity(
        actor=actor,
        data=activity,
    )

    with pytest.raises(ValueError):
        await simple_storage_publish_activity(
            msg, AsyncMock(), MagicMock(), AsyncMock()
        )


async def test_simple_storage_activity(sql_engine, test_actor):
    msg = PublishActivity(actor="http://alice.example", data=activity_stub)

    broker = AsyncMock()
    config = SimpleStorageConfiguration(prefix="/simple/storage/")

    async_session = async_sessionmaker(sql_engine, expire_on_commit=False)

    async with async_session() as session:
        await simple_storage_publish_activity(
            msg, config, broker=broker, session=session
        )
        await session.commit()

    broker.publish.assert_awaited_once()

    async with async_session() as session:
        result = (await session.scalars(select(StoredActivity))).all()

        assert len(result) == 1

        assert result[0].data.get("id")


@pytest.mark.parametrize(
    "actor,object",
    [
        ("http://bob.example", object_stub),
        (
            "http://alice.example",
            {**object_stub, "id": "http://alice.example/activity1"},
        ),
    ],
)
async def test_simple_storage_publish_object_errors(actor, object):
    msg = PublishObject(
        actor=actor,
        data=object,
    )

    with pytest.raises(ValueError):
        await simple_storage_publish_object(msg, AsyncMock(), MagicMock(), AsyncMock())


async def test_simple_storage_object(sql_engine, test_actor):
    obj = object_stub.copy()
    obj["attributedTo"] = test_actor.actor_id
    msg = PublishObject(actor=test_actor.actor_id, data=obj)

    broker = AsyncMock()
    config = SimpleStorageConfiguration(prefix="/simple/storage/")

    async_session = async_sessionmaker(sql_engine, expire_on_commit=False)

    async with async_session() as session:
        await simple_storage_publish_object(msg, config, broker=broker, session=session)
        await session.commit()

    broker.publish.assert_awaited_once()

    async with async_session() as session:
        result = (await session.scalars(select(StoredActivity))).all()

        assert len(result) == 1

        assert result[0].data.get("id")

        result = (await session.scalars(select(StoredObject))).all()

        assert len(result) == 1

        assert result[0].data.get("id")
